pub fn generate_wrapper_file(
entries: &[&FuncEntry],
ctx: &CodegenContext,
) -> StringExpand description
Generate a complete .cpp file with all wrapper functions for a class.
pub fn generate_wrapper_file(
entries: &[&FuncEntry],
ctx: &CodegenContext,
) -> StringGenerate a complete .cpp file with all wrapper functions for a class.