Module properties
uika_
codegen
0.1.0
Module properties
Module Items
Structs
Functions
In uika_
codegen::
rust_
gen
uika_codegen
::
rust_gen
Module
properties
Structs

Property
Context
Context that parameterizes property codegen for classes vs structs.
Functions

collect_
deduped_
properties
Collect supported, deduplicated properties, returning their getter name set and the property list. Properties referencing types not in the context (e.g., enums/classes from non-enabled modules) are filtered out.
default_
value_
for
Get a default value literal for a Rust type.
generate_
property
Generate a getter and setter for a single property (used as default impls in Ext trait).