pub struct MappedType {
pub rust_type: String,
pub rust_ffi_type: String,
pub cpp_type: String,
pub property_getter: String,
pub property_setter: String,
pub rust_to_ffi: ConversionKind,
pub ffi_to_rust: ConversionKind,
pub supported: bool,
}Expand description
Mapped type information for code generation.
Fields
rust_type: StringRust type in function signatures (e.g., “bool”, “i32”, “UObjectRef
rust_ffi_type: StringRust type for the FFI boundary (e.g., “bool”, “i32”, “UObjectHandle”).
cpp_type: StringC++ type for the wrapper function (e.g., “bool”, “int32”, “UObject*”).
property_getter: StringPropertyApi method name for getters (e.g., “get_bool”, “get_i32”).
property_setter: StringPropertyApi method name for setters.
rust_to_ffi: ConversionKindHow to convert from Rust safe type to FFI type in function call.
ffi_to_rust: ConversionKindHow to convert from FFI type to Rust safe type in return.
supported: boolWhether this is a supported type for Phase 3.